<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta charset="utf-8" />
		<title>Calresa</title>
        <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='style.css') }}" />
	</head>
	<body>
<h1>Calresa</h1>
{% block body %}
{% endblock %}
	</body>
</html>
